' Name: OpenRokn
' Homepage: http://openrokn.sourceforge.net
' Description: Open source Roku channel building kit
' Author: kavulix
' 
' Copyright (C) 2011 kavulix
' 
' Licensed under the Apache License, Version 2.0 (the "License");
' you may not use this file except in compliance with the License.
' You may obtain a copy of the License at
'
' http://www.apache.org/licenses/LICENSE-2.0
'
' Unless required by applicable law or agreed to in writing, software
' distributed under the License is distributed on an "AS IS" BASIS,
' WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
' See the License for the specific language governing permissions and
' limitations under the License.



Sub Main()
	canvas = createSplashScreen()
	canvas.Show()

	' the code in this Main function confirms the presence of 3 different
	' bugs in the Roku firmware.

	' the first bug involves the roMessageDialog component. the code below
	' should create and display a message dialog with a single cancel button.
	' the message dialog is successfully created and displayed but the button
	' is invisible. it doesnt matter how many buttons you try to add to the
	' dialog they will all be invisible. I have also tried adding a sleep(2000)
	' before and after calling Show() which has no effect on this bug.
	port = CreateObject("roMessagePort")
	dialog = createMessageDialog(port, "Loading...", "", true, false, true, [{index:1,label:"Cancel"}])
	dialog.Show()

	rowTitles = ["Row 1", "Row 2", "Row 3", "Row 4", "Row 5", "Row 6", "Row 7"]
	grid = CreateObject("roGridScreen")
	grid.SetBreadcrumbText("Breadcrumb 1", "Breadcrumb 2")
	grid.SetBreadcrumbEnabled(true)
	grid.SetGridStyle("flat-square")
	grid.SetDisplayMode("scale-to-fit")
	grid.SetDescriptionVisible(true)
	grid.SetUpBehaviorAtTopRow("exit")

	' the second bug involves the SetupLists() function. as soon as you call
	' that function the grid component begins intercepting all events preventing
	' any open dialogs from detecting when a button has been pressed. This bug
	' occurs before the Show() function has been called and occurs even if a
	' port has not been set on the grid. You can verify that all events are being
	' intercepted by the grid by pressing the up button. The channel will exit
	' indicating that the grid component is intercepting all remote button events.
	' Pressing enter will have no effect on the dialog button. If you comment out
	' the SetupLists line below then pressing up will have no effect and when you
	' press enter the dialog component will successfully detect the event. This
	' bug will still occur even if the SetMessagePort line is commented out.
	grid.SetupLists(rowTitles.Count())

	' The third bug involves setting a port on the grid component. If a port is set
	' on the grid then a grid event will occasionally be detected as soon as the
	' SetupLists function is called. The details will be printed in the while loop.
	' This doesnt occur everytime but at least every other time the channel loads.
	' Try loading and then exiting the channel at least 5 times to see the event
	' info printed. If you comment out the SetupLists line above then no grid event
	' is detected.
	'grid.SetMessagePort(port)

	while true
		msg = wait(0, port)
print type(msg)
print "isButtonPressed: ";msg.isButtonPressed()
print "isRemoteKeyPressed: ";msg.isRemoteKeyPressed()
print "isScreenClosed: ";msg.isScreenClosed()
print "isListItemFocused: ";msg.isListItemFocused()
print "isListItemSelected: ";msg.isListItemSelected()
print "GetType: ";msg.GetType()
print "GetMessage: ";msg.GetMessage()
print "GetIndex: ";msg.GetIndex()
print "GetData: ";msg.GetData()
		if type(msg) = "roMessageDialogEvent" then
			if msg.isButtonPressed() and msg.GetIndex() = 1 then
				print "canceled"
				dialog.Close()
				return
			endif
		endif
	end while
End Sub

Function createSplashScreen() As Object
	gaa = GetGlobalAA()
	gaa.constants = {}
	gaa.constants.splash = {}
	gaa.constants.splash.text = "openrokn.sourceforge.net"
	gaa.constants.splash.textColor = "#FFFFFF"
	gaa.constants.splash.bgroundColor = "#000000"
	gaa.constants.splash.imageUrl = "pkg:/images/powered_by_logo.png"

	dinfo = CreateObject("roDeviceInfo")
	dsize = dinfo.GetDisplaySize()
	dtype = dinfo.GetDisplayType()

	imageW = 131
	imageH = 69
	imageX = dsize.w - imageW - 40
	imageY = dsize.h - imageH - 20

	bground = {
		Color:gaa.constants.splash.bgroundColor, CompositionMode:"Source"
	}

	text = {
		Color:gaa.constants.splash.bgroundColor, CompositionMode:"Source_Over",
		Text:gaa.constants.splash.text,
		TextAttrs:{
			Color:gaa.constants.splash.textColor, Font:"Large",
			HAlign:"Center", VAlign:"Middle",
			TextDirection:"LeftToRight"
		}
	}

	image = {
		Color:gaa.constants.splash.bgroundColor, CompositionMode:"Source_Over",
		Url:gaa.constants.splash.imageUrl,
		TargetRect:{x:imageX,y:imageY,w:imageW,h:imageH}
	}

	canvas = CreateObject("roImageCanvas")
	canvas.AllowUpdates(true)
	canvas.SetLayer(0, bground)
	canvas.SetLayer(1, text)
	canvas.SetLayer(2, image)
	return canvas
End Function

